@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005, 2006, 2008 Free Software Foundation
+ * Copyright (C) 2005, 2006, 2008, 2009 Free Software Foundation
  *
  * Author: Simon Josefsson
  *
@@ -9,12 +9,12 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- *               
+ *
  * GNUTLS-EXTRA is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *                               
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -24,6 +24,7 @@
 #include "gnutls_errors.h"
 #include "gnutls_num.h"
 #include "gnutls_state.h"
+#include <gnutls/extra.h>
 
 #define CHECKSUM_SIZE 12
 
@@ -111,6 +112,7 @@ _gnutls_recv_inner_application (gnutls_session_t session,
 				opaque * data, size_t sizeofdata)
 {
   ssize_t len;
+  uint32_t len24;
   opaque pkt[4];
 
   len = _gnutls_recv_int (session, GNUTLS_INNER_APPLICATION, -1, pkt, 4);
@@ -121,28 +123,28 @@ _gnutls_recv_inner_application (gnutls_session_t session,
     }
 
   *msg_type = pkt[0];
-  len = _gnutls_read_uint24 (&pkt[1]);
+  len24 = _gnutls_read_uint24 (&pkt[1]);
 
-  if (*msg_type != GNUTLS_IA_APPLICATION_PAYLOAD && len != CHECKSUM_SIZE)
+  if (*msg_type != GNUTLS_IA_APPLICATION_PAYLOAD && len24 != CHECKSUM_SIZE)
     {
       gnutls_assert ();
       return GNUTLS_E_UNEXPECTED_PACKET_LENGTH;
     }
 
-  if (sizeofdata < len)
+  if (sizeofdata < len24)
     {
       /* XXX push back pkt to IA buffer? */
       gnutls_assert ();
       return GNUTLS_E_SHORT_MEMORY_BUFFER;
     }
 
-  if (len > 0)
+  if (len24 > 0)
     {
-      int tmplen = len;
+      uint32_t tmplen = len24;
 
-      len = _gnutls_recv_int (session, GNUTLS_INNER_APPLICATION, -1,
-			      data, tmplen);
-      if (len != tmplen)
+      len24 = _gnutls_recv_int (session, GNUTLS_INNER_APPLICATION, -1,
+				data, tmplen);
+      if (len24 != tmplen)
 	{
 	  gnutls_assert ();
 	  /* XXX Correct? */
@@ -150,7 +152,7 @@ _gnutls_recv_inner_application (gnutls_session_t session,
 	}
     }
 
-  return len;
+  return len24;
 }
 
 /* Apply the TLS PRF using the TLS/IA inner secret as keying material,
@@ -374,8 +376,8 @@ gnutls_ia_verify_endphase (gnutls_session_t session, const char *checksum)
  * @sizeofdata: is the length of the data
  *
  * Send TLS/IA application payload data.  This function has the
- * similar semantics with send(). The only difference is that is
- * accepts a GNUTLS session, and uses different error codes.
+ * similar semantics with send().  The only difference is that it
+ * accepts a GnuTLS session, and uses different error codes.
  *
  * The TLS/IA protocol is synchronous, so you cannot send more than
  * one packet at a time.  The client always send the first packet.
@@ -413,7 +415,7 @@ gnutls_ia_send (gnutls_session_t session, const char *data, size_t sizeofdata)
  * @sizeofdata: the number of requested bytes, must be >= 12.
  *
  * Receive TLS/IA data.  This function has the similar semantics with
- * recv(). The only difference is that is accepts a GNUTLS session,
+ * recv().  The only difference is that it accepts a GnuTLS session,
  * and uses different error codes.
  *
  * If the server attempt to finish an application phase, this function
@@ -633,7 +635,8 @@ gnutls_ia_handshake_p (gnutls_session_t session)
  * Perform a TLS/IA handshake.  This should be called after
  * gnutls_handshake() iff gnutls_ia_handshake_p().
  *
- * Return 0 on success, or an error code.
+ * Returns: On success, %GNUTLS_E_SUCCESS (zero) is returned,
+ *   otherwise an error code is returned.
  **/
 int
 gnutls_ia_handshake (gnutls_session_t session)
@@ -650,7 +653,7 @@ gnutls_ia_handshake (gnutls_session_t session)
 
 /**
  * gnutls_ia_allocate_client_credentials - Used to allocate an gnutls_ia_server_credentials_t structure
- * @sc: is a pointer to an #gnutls_ia_server_credentials_t structure.
+ * @sc: is a pointer to a #gnutls_ia_server_credentials_t structure.
  *
  * This structure is complex enough to manipulate directly thus this
  * helper function is provided in order to allocate it.
@@ -676,7 +679,7 @@ gnutls_ia_allocate_client_credentials (gnutls_ia_client_credentials_t * sc)
 
 /**
  * gnutls_ia_free_client_credentials - Used to free an allocated #gnutls_ia_client_credentials_t structure
- * @sc: is an #gnutls_ia_client_credentials_t structure.
+ * @sc: is a #gnutls_ia_client_credentials_t structure.
  *
  * This structure is complex enough to manipulate directly thus this
  * helper function is provided in order to free (deallocate) it.
@@ -760,7 +763,7 @@ gnutls_ia_get_client_avp_ptr (gnutls_ia_client_credentials_t cred)
 
 /**
  * gnutls_ia_allocate_server_credentials - Used to allocate an gnutls_ia_server_credentials_t structure
- * @sc: is a pointer to an #gnutls_ia_server_credentials_t structure.
+ * @sc: is a pointer to a #gnutls_ia_server_credentials_t structure.
  *
  * This structure is complex enough to manipulate directly thus this
  * helper function is provided in order to allocate it.
@@ -786,7 +789,7 @@ gnutls_ia_allocate_server_credentials (gnutls_ia_server_credentials_t * sc)
 
 /**
  * gnutls_ia_free_server_credentials - Used to free an allocated #gnutls_ia_server_credentials_t structure
- * @sc: is an #gnutls_ia_server_credentials_t structure.
+ * @sc: is a #gnutls_ia_server_credentials_t structure.
  *
  * This structure is complex enough to manipulate directly thus this
  * helper function is provided in order to free (deallocate) it.
@@ -822,7 +825,7 @@ gnutls_ia_free_server_credentials (gnutls_ia_server_credentials_t sc)
  * client, and to get a new AVP to send to the client.  It can also be
  * used to instruct the TLS/IA handshake to do go into the
  * Intermediate or Final phases.  It return a negative error code, or
- * an #gnutls_ia_apptype_t message type.
+ * a #gnutls_ia_apptype_t message type.
  *
  * The callback may invoke gnutls_ia_permute_inner_secret() to mix any
  * generated session keys with the TLS/IA inner secret.
